@@ -6,11 +6,11 @@ void header(int argc, char **argv)
 
     cout << 
         arg.basename() << " by " << Icmbuild::author << '\n' <<
-        arg.basename() << " V" << Icmbuild::version << ' ' << 
+        arg.basename() << " V " << Icmbuild::version << ' ' << 
                                                     Icmbuild::years << "\n"
         "\n"
         "CREATED " << DateTime().rfc2822() << "\n"
-        "CROSS REFERENCE FOR: ";
+        "OXREF ARGUMENTS: ";
 
     copy(argv + 1, argv + argc, ostream_iterator<char const *>(cout, " "));
 
