@@ -21,13 +21,13 @@ std::ostream &Store::insertInto(std::ostream &out) const
             [&](size_t left, size_t right)
             {
                 return 
-                    strcasecmp(d_xrefData[left].name(), 
-                               d_xrefData[right].name()) < 0;
+                    strcasecmp(d_xrefVector[left].name(), 
+                               d_xrefVector[right].name()) < 0;
             }
         );
 
         for (auto idx: d_defIdx)    
-            insertDefined(idx, out, d_xrefData);
+            insertDefined(idx, out, d_xrefVector);
     }
 
     return out;
