@@ -4,7 +4,7 @@
 
 namespace {
 
-char const usageText[] = R"((
+char const usageText[] = R"(
 Where:
    [options] - optional arguments (short options between parentheses):
 
@@ -12,6 +12,8 @@ Where:
               count - display function argument counts only
               first - only display the first word of the parameter types
               <len> - restrict parameter types to the first <len> characters
+      --called-by (-c) regex  - display (recursively) the function(s) calling 
+                                the function specified at 'regex'.
       --full-symbol (-f)      - display the full symbol names (e.g.,
                                 including class name prefixes)
       --help (-h)             - provide this help
@@ -42,14 +44,14 @@ Where:
    args   - non-stripped .o or libraries whose symbols must be
             cross-referenced.
 
-))";
+)";
 
 }   // namespace
 void usage(std::string const &progname)
 {
     cout << '\n' <<
     progname << " by " << Icmbuild::author << '\n' <<
-    progname << " V" << Icmbuild::version << " " << Icmbuild::years << "\n"
+    progname << " V " << Icmbuild::version << " " << Icmbuild::years << "\n"
     "\n"
     "Usage: " << progname << " [options] args" <<
     usageText;
